==> reverie_dreams-0.4.3%2B1.21.7%2Bbeta-sources.jar: cc/thonly/reverie_dreams/item/weapon/WindBlessingCane.java <==
package cc.thonly.reverie_dreams.item.weapon;

import cc.thonly.reverie_dreams.data.ModTags;
import cc.thonly.reverie_dreams.item.base.SwordItem;
import net.minecraft.class_1309;
import net.minecraft.class_1676;
import net.minecraft.class_1799;
import net.minecraft.class_1937;
import net.minecraft.class_3218;
import net.minecraft.class_3417;
import net.minecraft.class_3419;
import net.minecraft.class_3489;
import net.minecraft.class_8956;
import net.minecraft.class_9886;

public class WindBlessingCane extends SwordItem {
    public static final class_9886 WIND_BLESSING_CANE = new class_9886(ModTags.BlockTypeTag.EMPTY, 250, 4.0f, 3.5f, 5, class_3489.field_52382);

    public WindBlessingCane(float attackDamage, float attackSpeed, class_1793 settings) {
        super(WIND_BLESSING_CANE,attackDamage, attackSpeed, settings);
    }

    @Override
    public void method_7873(class_1799 stack, class_1309 target, class_1309 attacker) {
        class_1937 world = target.method_37908();
        if (!world.method_8608() && world instanceof class_3218 serverWorld) {
            if (serverWorld.field_9229.method_43057() < 0.2f) {
                class_1676.method_61549((w, s, st) -> new class_8956(w, s.method_23317(), s.method_23318(), s.method_23321(), s.method_18798()), serverWorld, this.method_7854(), attacker, 0.0f, 1.5f, 1.0f);
                serverWorld.method_43128(null, attacker.method_23317(), attacker.method_23318(), attacker.method_23321(), class_3417.field_49045, class_3419.field_15254, 0.5f, 0.4f / (serverWorld.method_8409().method_43057() * 0.4f + 0.8f));
            }
        }
        super.method_7873(stack, target, attacker);
    }
}

==> reverie_dreams-0.4.7%2B1.21.7%2Bbeta-sources.jar: cc/thonly/reverie_dreams/item/weapon/WindBlessingCane.java <==
package cc.thonly.reverie_dreams.item.weapon;

import cc.thonly.reverie_dreams.registry.tag.RDBlockTags;
import net.minecraft.class_1309;
import net.minecraft.class_1676;
import net.minecraft.class_1799;
import net.minecraft.class_1937;
import net.minecraft.class_3218;
import net.minecraft.class_3417;
import net.minecraft.class_3419;
import net.minecraft.class_3489;
import net.minecraft.class_8956;
import net.minecraft.class_9886;
import cc.thonly.reverie_dreams.item.base.SwordItem;

public class WindBlessingCane extends SwordItem {
    public static final class_9886 WIND_BLESSING_CANE = new class_9886(RDBlockTags.EMPTY, 250, 4.0f, 3.5f, 5, class_3489.field_52382);

    public WindBlessingCane(float attackDamage, float attackSpeed, class_1793 settings) {
        super(WIND_BLESSING_CANE,attackDamage, attackSpeed, settings);
    }

    @Override
    public void method_7873(class_1799 stack, class_1309 target, class_1309 attacker) {
        class_1937 world = target.method_37908();
        if (!world.method_8608() && world instanceof class_3218 serverWorld) {
            if (serverWorld.field_9229.method_43057() < 0.2f) {
                class_1676.method_61549((w, s, st) -> new class_8956(w, s.method_23317(), s.method_23318(), s.method_23321(), s.method_18798()), serverWorld, this.method_7854(), attacker, 0.0f, 1.5f, 1.0f);
                serverWorld.method_43128(null, attacker.method_23317(), attacker.method_23318(), attacker.method_23321(), class_3417.field_49045, class_3419.field_15254, 0.5f, 0.4f / (serverWorld.method_8409().method_43057() * 0.4f + 0.8f));
            }
        }
        super.method_7873(stack, target, attacker);
    }
}
